ReportLab Preppy Test Suite 002

# Preppy Test 002 - Loops in Python and Preppy Tag

This tests for and while loops as chunks of embedded Python code between script and endscript tags. Then it tests loops using the preppy for and while tags. The output should look the same.

## Expected Output

You should see four sets of the numbers 1 to 10 between the lines:
Set 1: Python 'for' loop
Set 2: Python 'while' loop
Set 3: Preppy 'for' loop
Set 4: Preppy 'while' loop

FOR loop between script..endscript: | 1 2 3 4 5 6 7 8 9 10 | Python FOR loop works OK
WHILE loop between script..endscript: | 1 2 3 4 5 6 7 8 9 10 | Python WHILE loop works OK
FOR loop in Preppy control structures: | 1 2 3 4 5 6 7 8 9 10 | Preppy FOR loop works OK
WHILE loop in Preppy control structures: | 1 2 3 4 5 6 7 8 9 10 | Preppy WHILE loop works OK